@@ -1,11 +1,14 @@
 import pkgutil
 import re
 import sys
+import types
 from importlib import import_module
 from inspect import signature
-from typing import Dict, Any, Optional
+from typing import Dict, Any, Optional, Callable
 
 from pyspark.ml import Transformer
+from spark_auto_mapper.automapper_base import AutoMapperBase
+
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
 
 
@@ -36,6 +39,30 @@ def get_python_transformer_from_location(location: str,
         return my_class()
 
 
+def get_python_function_from_location(location: str,
+                                      import_module_name: str
+                                      ) -> Callable[[Dict[str, Any]], AutoMapperBase]:
+    assert location
+    search = re.search(r'/library/', location)
+    assert search
+    lib_path = location[search.start() + 1:].replace('/', '.').replace('', '')
+    # load_all_modules_from_dir(location)
+    module = import_module(import_module_name, lib_path)
+    md = module.__dict__
+    # noinspection PyTypeChecker
+    my_function: Callable[[Dict[str, Any]], AutoMapperBase] = [
+        md[c] for c in md if isinstance(md[c], types.FunctionType)
+    ][0]
+    my_function_signature = signature(my_function)
+    my_function_args = [
+        param for param in my_function_signature.parameters.values() if param.name != 'self'
+    ]
+    # now figure out the function_parameters has one and only one parameter: parameters
+    assert len(my_function_args) == 1
+    assert my_function_args[0].name == "parameters"
+    return my_function
+
+
 def load_all_modules_from_dir(dirname):
     for importer, package_name, _ in pkgutil.iter_modules([dirname]):
         full_package_name = '%s.%s' % (dirname, package_name)
